@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of MIDI files
 
-our $VERSION = '0.1600';
+our $VERSION = '0.1601';
 
 use Moo;
 use strictures 2;
@@ -481,7 +481,7 @@ sub dura_convert {
                 }
             }
 
-            push @csv, $match ? $dura : 'd' . $n;
+            push @csv, $match ? $dura : 'd' . $v;
             $match = 0;
         }
 
@@ -550,7 +550,7 @@ MIDI::Ngram - Find the top repeated note phrases of MIDI files
 
 =head1 VERSION
 
-version 0.1600
+version 0.1601
 
 =head1 SYNOPSIS
 
